%tesa_latex_plot_multi_open open a file for multi plot values in a latex file
%  tesa_latex_plot_multi_open.m
%
%  Author:         Serge Fabre
%  Date Created:   Nov 13 2019
%  
%   Arguments :                   
%   	Path : Path to the directoy of the latex document
%       Label : Label of the figure used by '\re{Label}' in the document
%       Caption : Caption of the gigure
%       X : X values Matrix 1 x M  M is the number of values
%       LogX :  Boolean for log X scale
%       LogY : Boolean for log Y scale%     
%       H : Height of a plot cm
%       W : Width of a plot cm
%       Rows : Number of Rows for plots
%       Columns : Number of Columns for plots
%       YLim : Limits of Y scale (optional)
%   return fileID : Handle of the file
%
%  The calling syntax is:
% 
%   fileID = tesa_latex_plot_multi_open(Path,Label,Caption,X,LogX,LogY,H,W,Rows,Columns,YLim)
% 
%  Copyright 2019 The TESA, Inc.
% 
function fileID = tesa_latex_plot_multi_open(Path,Label,Caption,X,LogX,LogY,H,W,Rows,Columns,YLim)
%UNTITLED Summary of this function goes here
%   Detailed explanation goes here
fileID = fopen([Path,'/',Label,'.tex'],'wt'); 
fprintf(fileID,'\t\\begin{figure}[H]\n');
fprintf(fileID,'\t\t\\begin{center}\n');
fprintf(fileID,'\t\t\t\\caption{%s}\n',Caption);
fprintf(fileID,'\t\t\t\\tikzstyle{int}=[draw, fill=blue!20, minimum size=2em]\n');
fprintf(fileID,'\t\t\t\\tikzstyle{init} = [pin edge={to-,thin,black}]\n');
fprintf(fileID,'\t\t\t\\begin{tikzpicture}\n');
fprintf(fileID,'\t\t\t\\begin{groupplot}[\n');
fprintf(fileID,'\t\t\tgroup style={group size=%d by %d,vertical sep=2cm},\n',Columns,Rows);
fprintf(fileID,'\t\t\theight=%fcm,\n',H);
fprintf(fileID,'\t\t\twidth=%fcm,\n',W);
fprintf(fileID,'\t\t\tgrid=major,\n');	
if(LogX==true)
    fprintf(fileID,'\t\t\txmode=log,\n');
end
if(LogY==true)
    fprintf(fileID,'\t\t\tymode=log,\n');
end
fprintf(fileID,'\t\t\txmin=%e,\n',X(1));
fprintf(fileID,'\t\t\txmax=%e,\n',X(end));
if exist('YLim','var')
    fprintf(fileID,'\t\t\tymin=%e,\n',YLim(1));
    fprintf(fileID,'\t\t\tymax=%e]\n',YLim(end));
else
    fprintf(fileID,']\n');
end
fprintf(fileID,'\t\t\t]\n');   
end

